pub struct QueryParams {
pub limit_per_record: Option<usize>,
pub start_time: Option<u64>,
pub end_time: Option<u64>,
}Expand description
Parameters for PersistenceBackend::query.
Fields
limit_per_record: Option<usize>For pattern queries: maximum number of results per matching record.
start_time: Option<u64>Only return values stored at or after this timestamp (Unix ms).
end_time: Option<u64>Only return values stored at or before this timestamp (Unix ms).